SKILL_FILENAME = "SKILL.md"
INJECTION_FILENAME = "injection.py"

MAX_NAME_LENGTH = 64
MAX_DESCRIPTION_LENGTH = 1024

# Name must be lowercase alphanumeric and hyphens only
NAME_PATTERN = r"^[a-z0-9]+(-[a-z0-9]+)*$"
